package com.link.core.util;

import com.link.base.user.model.CoreUser;
import com.link.core.basic.model.UploadImgInfo;
import com.link.core.cllog.LCLogger;
import java.awt.Image;
import java.awt.image.BufferedImage;
import java.awt.image.ImageObserver;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Date;
import javax.imageio.ImageIO;
import org.apache.http.entity.ContentType;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.core.env.Environment;
import org.springframework.mock.web.MockMultipartFile;
import org.springframework.web.multipart.MultipartFile;
import sun.misc.BASE64Decoder;
import sun.misc.BASE64Encoder;

public final class ImageUtil {
   private static final Logger logger = LogManager.getLogger(ImageUtil.class);
   private static final String[] CHARS = new String[]{"0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "A", "B", "C", "D", "E", "F", "G", "H", "I"};
   private static final int SIZE = 4;
   private static final int LINES = 10;
   private static final int WIDTH = 150;
   private static final int HEIGHT = 70;
   private static final int FONT_SIZE = 40;
   static BASE64Encoder encoder = new BASE64Encoder();
   static BASE64Decoder decoder = new BASE64Decoder();
   private static int currentImageIndex = 0;
   private static float quality = 0.5F;
   private static float B_quality = 0.5F;
   private static int MAX_SIZE = 400;
   private static int L_MAX_SIZE = 300;

   public static String getLessUploadFileName(String fileName) {
      return fileName + "less.jpg";
   }

   public static String getUploadFileName(String fileName) {
      return fileName + ".jpg";
   }

   public static String getLessUploadPath() {
      return System.getProperty("user.dir") + File.separator + "lessUpload" + File.separator;
   }

   public static String getUploadPath() {
      return System.getProperty("user.dir") + File.separator + "upload" + File.separator;
   }

   public static String getCommonFolder() {
      CoreUser user = UserUtil.getUser();
      String userName = "anonymity";
      if (user != null) {
         userName = user.getUsername();
      } else {
         logger.info("获取用户对象失败...");
      }

      return "/" + DateUtil.dateToStr(new Date(), "yyyy-MM-dd") + "/" + userName;
   }

   public static String getLogin() {
      CoreUser user = UserUtil.getUser();
      return user.getUsername();
   }

   public static synchronized String makeImage(String srcStr, String fileName, String path, String category) throws Exception {
      String filePath = "/app/" + category + "/image/" + fileName;
      String fileRelatePath = path + filePath;
      String fileFolder = path + "/app/" + category + "/image";
      File file = new File(fileFolder);
      if (!file.exists()) {
         logger.info("文件夹路径不存在，创建文件夹【" + fileFolder + "】");
         boolean isCreateSuccess = file.mkdirs();
         if (isCreateSuccess) {
            logger.info("Create folder【" + fileFolder + "】 Success");
         } else {
            logger.error("Create folder 【" + fileFolder + "】 Failed");
         }
      }

      if (!file.isDirectory()) {
         logger.error(fileFolder + "is not a file directory!");
      } else if (!file.canRead()) {
         logger.error("this folder can't be read " + fileFolder);
      } else if (!file.canWrite()) {
         logger.error("this folder can't be write " + fileFolder);
      }

      file = new File(fileRelatePath);
      if (file.exists()) {
         throw new Exception("文件已经存在，保存文件失败！");
      } else {
         byte[] bytes1 = decoder.decodeBuffer(srcStr);

         for(int i = 0; i < bytes1.length; ++i) {
            if (bytes1[i] < 0) {
               bytes1[i] = (byte)(bytes1[i] + 256);
            }
         }

         OutputStream out = new FileOutputStream(file);
         Throwable var10 = null;

         try {
            out.write(bytes1);
            out.flush();
            out.close();
         } catch (Throwable var19) {
            var10 = var19;
            throw var19;
         } finally {
            if (out != null) {
               if (var10 != null) {
                  try {
                     out.close();
                  } catch (Throwable var18) {
                     var10.addSuppressed(var18);
                  }
               } else {
                  out.close();
               }
            }

         }

         return filePath;
      }
   }

   public static synchronized String makeImage(String srcStr, String fileName) throws Exception {
      String fileFolder = "/app/share/io/makesmallTemp/image";
      String fileRelatePath = fileFolder + "/" + fileName;
      File file = new File(fileFolder);
      if (!file.exists()) {
         logger.info("文件夹路径不存在，创建文件夹【" + fileFolder + "】");
         boolean isCreateSuccess = file.mkdirs();
         if (isCreateSuccess) {
            logger.info("Create folder【" + fileFolder + "】 Success");
         } else {
            logger.error("Create folder 【" + fileFolder + "】 Failed");
         }
      }

      if (!file.isDirectory()) {
         logger.error(fileFolder + "is not a file directory!");
      } else if (!file.canRead()) {
         logger.error("this folder can't be read " + fileFolder);
      } else if (!file.canWrite()) {
         logger.error("this folder can't be write " + fileFolder);
      }

      file = new File(fileRelatePath);
      if (file.exists()) {
         throw new Exception("文件已经存在，保存文件失败！");
      } else {
         byte[] bytes1 = decoder.decodeBuffer(srcStr);

         for(int i = 0; i < bytes1.length; ++i) {
            if (bytes1[i] < 0) {
               bytes1[i] = (byte)(bytes1[i] + 256);
            }
         }

         OutputStream out = new FileOutputStream(file);
         Throwable var7 = null;

         try {
            out.write(bytes1);
            out.flush();
            out.close();
         } catch (Throwable var16) {
            var7 = var16;
            throw var16;
         } finally {
            if (out != null) {
               if (var7 != null) {
                  try {
                     out.close();
                  } catch (Throwable var15) {
                     var7.addSuppressed(var15);
                  }
               } else {
                  out.close();
               }
            }

         }

         return fileRelatePath;
      }
   }

   public static UploadImgInfo saveImageAndLessImage(String strImg, String category, String parentId) throws Exception {
      strImg = strImg.substring(strImg.lastIndexOf(",") + 1);
      UploadImgInfo uploadImgInfo = new UploadImgInfo();
      CoreUser user = UserUtil.getUser();
      if (user == null) {
         logger.info("获取用户对象失败,采用随机码...");
         user = new CoreUser();
         user.setUsername(StringUtils.getRandomCharAndNumr(8));
      }

      String commonName = user.getUsername() + DateUtil.dateToStr(new Date(), "yyyyMMddHHmmssSSS") + "_" + getNextImageIndex();
      String fileName = getUploadFileName(commonName);
      String filePath = makeImage(strImg, fileName, CoreYmlConstants.getPortalShareFileDir(), category);
      File f = new File(CoreYmlConstants.getPortalShareFileDir() + filePath);
      if (f.exists() && f.isFile()) {
         uploadImgInfo.setFileSize(String.valueOf(f.length()));
      } else {
         uploadImgInfo.setFileSize("0");
      }

      String fileLessRelatePath = makeSmallImage(CoreYmlConstants.getPortalShareFileDir() + filePath, fileName, CoreYmlConstants.getPortalShareFileDir(), category);
      String bigLessRelatePath = makeBigSmallImage(CoreYmlConstants.getPortalShareFileDir() + filePath, fileName, CoreYmlConstants.getPortalShareFileDir(), category);
      uploadImgInfo.setFileName(fileName);
      uploadImgInfo.setFilePath(filePath);
      uploadImgInfo.setFileHttpPath(CoreYmlConstants.getPortalShareUrlDir() + filePath);
      uploadImgInfo.setFileLessPath(fileLessRelatePath);
      uploadImgInfo.setFileLessHtppPath(CoreYmlConstants.getPortalShareUrlDir() + fileLessRelatePath);
      uploadImgInfo.setBigfilePath(bigLessRelatePath);
      uploadImgInfo.setBigfileHtppPath(CoreYmlConstants.getPortalShareUrlDir() + bigLessRelatePath);
      return uploadImgInfo;
   }

   public static UploadImgInfo saveImageAndLessImage(String strImg, String fileName) throws Exception {
      strImg = strImg.substring(strImg.lastIndexOf(",") + 1);
      UploadImgInfo uploadImgInfo = new UploadImgInfo();
      String filePath = makeImage(strImg, fileName);
      File f = new File(filePath);
      if (f.exists() && f.isFile()) {
         uploadImgInfo.setFileSize(String.valueOf(f.length()));
      } else {
         uploadImgInfo.setFileSize("0");
      }

      String fileLessRelatePath = makeSmallImage(filePath, fileName);
      String bigLessRelatePath = makeBigSmallImage(filePath, fileName);
      uploadImgInfo.setFileName(fileName);
      uploadImgInfo.setFilePath(filePath);
      uploadImgInfo.setFileLessPath(fileLessRelatePath);
      uploadImgInfo.setBigfilePath(bigLessRelatePath);
      return uploadImgInfo;
   }

   public static String makeBigSmallImage(String srcFilePath, String fileName, String path, String category) throws Exception {
      String endPath = "/app/" + category + "/imageless/" + fileName;
      String filePath = path + endPath;
      String fileFolder = path + "/app/" + category + "/imageless";
      File file = new File(fileFolder);
      if (!file.exists()) {
         logger.info("文件夹路径不存在，创建文件夹【" + fileFolder + "】");
         boolean isCreateSuccess = file.mkdirs();
         if (isCreateSuccess) {
            logger.info("Create folder【" + fileFolder + "】 Success");
         } else {
            logger.error("Create folder 【" + fileFolder + "】 Failed");
         }
      }

      if (!file.isDirectory()) {
         logger.error(fileFolder + "is not a file directory!");
      } else if (!file.canRead()) {
         logger.error("this folder can't be read " + fileFolder);
      } else if (!file.canWrite()) {
         logger.error("this folder can't be write " + fileFolder);
      }

      file = new File(filePath);
      if (file.exists()) {
         throw new Exception("文件已经存在，保存文件失败！");
      } else {
         Boolean createNewFileFlag = file.createNewFile();
         if (createNewFileFlag) {
            logger.info("文件创建成功");
         } else {
            logger.error("文件创建失败");
         }

         FileOutputStream fileOutputStream = null;
         BufferedImage tagImage = null;
         Image srcImage = null;

         try {
            srcImage = ImageIO.read(new File(srcFilePath));
            int srcWidth = srcImage.getWidth((ImageObserver)null);
            int srcHeight = srcImage.getHeight((ImageObserver)null);
            int dstMaxSize = MAX_SIZE;
            int dstWidth = srcWidth;
            int dstHeight = srcHeight;
            float scale = 0.0F;
            if (srcWidth > dstMaxSize) {
               dstWidth = dstMaxSize;
               scale = (float)srcWidth / (float)dstMaxSize;
               dstHeight = Math.round((float)srcHeight / scale);
            }

            srcHeight = dstHeight;
            if (srcHeight > dstMaxSize) {
               dstHeight = dstMaxSize;
               scale = (float)srcHeight / (float)dstMaxSize;
               dstWidth = Math.round((float)dstWidth / scale);
            }

            tagImage = new BufferedImage(dstWidth, dstHeight, 1);
            tagImage.getGraphics().drawImage(srcImage, 0, 0, dstWidth, dstHeight, (ImageObserver)null);
            fileOutputStream = new FileOutputStream(filePath);
            ImageIO.write(tagImage, "jpeg", fileOutputStream);
            fileOutputStream.close();
            fileOutputStream = null;
         } finally {
            if (fileOutputStream != null) {
               try {
                  fileOutputStream.close();
               } catch (Exception var23) {
                  Exception e = var23;
                  logger.error(e);
               }

               fileOutputStream = null;
            }

            encoder = null;
            tagImage = null;
            srcImage = null;
            System.gc();
         }

         return endPath;
      }
   }

   public static String makeBigSmallImage(String srcFilePath, String fileName) throws Exception {
      String fileFolder = "/app/share/io/makesmallTemp/imageless";
      String fileRelatePath = fileFolder + "/" + fileName;
      File file = new File(fileFolder);
      if (!file.exists()) {
         logger.info("文件夹路径不存在，创建文件夹【" + fileFolder + "】");
         boolean isCreateSuccess = file.mkdirs();
         if (isCreateSuccess) {
            logger.info("Create folder【" + fileFolder + "】 Success");
         } else {
            logger.error("Create folder 【" + fileFolder + "】 Failed");
         }
      }

      if (!file.isDirectory()) {
         logger.error(fileFolder + "is not a file directory!");
      } else if (!file.canRead()) {
         logger.error("this folder can't be read " + fileFolder);
      } else if (!file.canWrite()) {
         logger.error("this folder can't be write " + fileFolder);
      }

      file = new File(fileRelatePath);
      if (file.exists()) {
         throw new Exception("文件已经存在，保存文件失败！");
      } else {
         Boolean createNewFileFlag = file.createNewFile();
         if (createNewFileFlag) {
            logger.info("文件创建成功");
         } else {
            logger.error("文件创建失败");
         }

         FileOutputStream fileOutputStream = null;
         BufferedImage tagImage = null;
         Image srcImage = null;

         try {
            srcImage = ImageIO.read(new File(srcFilePath));
            int srcWidth = srcImage.getWidth((ImageObserver)null);
            int srcHeight = srcImage.getHeight((ImageObserver)null);
            int dstMaxSize = MAX_SIZE;
            int dstWidth = srcWidth;
            int dstHeight = srcHeight;
            float scale = 0.0F;
            if (srcWidth > dstMaxSize) {
               dstWidth = dstMaxSize;
               scale = (float)srcWidth / (float)dstMaxSize;
               dstHeight = Math.round((float)srcHeight / scale);
            }

            srcHeight = dstHeight;
            if (srcHeight > dstMaxSize) {
               dstHeight = dstMaxSize;
               scale = (float)srcHeight / (float)dstMaxSize;
               dstWidth = Math.round((float)dstWidth / scale);
            }

            tagImage = new BufferedImage(dstWidth, dstHeight, 1);
            tagImage.getGraphics().drawImage(srcImage, 0, 0, dstWidth, dstHeight, (ImageObserver)null);
            fileOutputStream = new FileOutputStream(fileRelatePath);
            ImageIO.write(tagImage, "jpeg", fileOutputStream);
            fileOutputStream.close();
            fileOutputStream = null;
         } finally {
            if (fileOutputStream != null) {
               try {
                  fileOutputStream.close();
               } catch (Exception var20) {
                  Exception e = var20;
                  logger.error(e);
               }

               fileOutputStream = null;
            }

            encoder = null;
            tagImage = null;
            srcImage = null;
            System.gc();
         }

         return fileRelatePath;
      }
   }

   public static String makeSmallImage(String srcFilePath, String fileName, String path, String category) throws Exception {
      String endPath = "/app/" + category + "/bigimage/" + fileName;
      String filePath = path + endPath;
      String fileFolder = path + "/app/" + category + "/bigimage";
      File file = new File(fileFolder);
      if (!file.exists()) {
         logger.info("文件夹路径不存在，创建文件夹【" + fileFolder + "】");
         boolean isCreateSuccess = file.mkdirs();
         if (isCreateSuccess) {
            logger.info("Create folder【" + fileFolder + "】 Success");
         } else {
            logger.error("Create folder 【" + fileFolder + "】 Failed");
         }
      }

      if (!file.isDirectory()) {
         logger.error(fileFolder + "is not a file directory!");
      } else if (!file.canRead()) {
         logger.error("this folder can't be read " + fileFolder);
      } else if (!file.canWrite()) {
         logger.error("this folder can't be write " + fileFolder);
      }

      file = new File(filePath);
      if (file.exists()) {
         throw new Exception("文件已经存在，保存文件失败！");
      } else {
         Boolean createNewFileFlag = file.createNewFile();
         if (createNewFileFlag) {
            logger.info("文件创建成功");
         } else {
            logger.error("文件创建失败");
         }

         FileOutputStream fileOutputStream = null;
         BufferedImage tagImage = null;
         Image srcImage = null;

         try {
            srcImage = ImageIO.read(new File(srcFilePath));
            int srcWidth = srcImage.getWidth((ImageObserver)null);
            int srcHeight = srcImage.getHeight((ImageObserver)null);
            int dstMaxSize = L_MAX_SIZE;
            int dstWidth = srcWidth;
            int dstHeight = srcHeight;
            float scale = 0.0F;
            if (srcWidth > dstMaxSize) {
               dstWidth = dstMaxSize;
               scale = (float)srcWidth / (float)dstMaxSize;
               dstHeight = Math.round((float)srcHeight / scale);
            }

            srcHeight = dstHeight;
            if (srcHeight > dstMaxSize) {
               dstHeight = dstMaxSize;
               scale = (float)srcHeight / (float)dstMaxSize;
               dstWidth = Math.round((float)dstWidth / scale);
            }

            tagImage = new BufferedImage(dstWidth, dstHeight, 1);
            tagImage.getGraphics().drawImage(srcImage, 0, 0, dstWidth, dstHeight, (ImageObserver)null);
            fileOutputStream = new FileOutputStream(filePath);
            ImageIO.write(tagImage, "jpeg", fileOutputStream);
            fileOutputStream.close();
            fileOutputStream = null;
         } finally {
            if (fileOutputStream != null) {
               try {
                  fileOutputStream.close();
               } catch (Exception var23) {
                  Exception e = var23;
                  logger.error(e);
               }

               fileOutputStream = null;
            }

            encoder = null;
            tagImage = null;
            srcImage = null;
            System.gc();
         }

         return endPath;
      }
   }

   public static String makeSmallImage(String srcFilePath, String fileName) throws Exception {
      String fileFolder = "/app/share/io/makesmallTemp/bigimage";
      String fileRelatePath = fileFolder + "/" + fileName;
      File file = new File(fileFolder);
      if (!file.exists()) {
         logger.info("文件夹路径不存在，创建文件夹【" + fileFolder + "】");
         boolean isCreateSuccess = file.mkdirs();
         if (isCreateSuccess) {
            logger.info("Create folder【" + fileFolder + "】 Success");
         } else {
            logger.error("Create folder 【" + fileFolder + "】 Failed");
         }
      }

      if (!file.isDirectory()) {
         logger.error(fileFolder + "is not a file directory!");
      } else if (!file.canRead()) {
         logger.error("this folder can't be read " + fileFolder);
      } else if (!file.canWrite()) {
         logger.error("this folder can't be write " + fileFolder);
      }

      file = new File(fileRelatePath);
      if (file.exists()) {
         throw new Exception("文件已经存在，保存文件失败！");
      } else {
         Boolean createNewFileFlag = file.createNewFile();
         if (createNewFileFlag) {
            logger.info("文件创建成功");
         } else {
            logger.error("文件创建失败");
         }

         FileOutputStream fileOutputStream = null;
         BufferedImage tagImage = null;
         Image srcImage = null;

         try {
            srcImage = ImageIO.read(new File(srcFilePath));
            int srcWidth = srcImage.getWidth((ImageObserver)null);
            int srcHeight = srcImage.getHeight((ImageObserver)null);
            int dstMaxSize = L_MAX_SIZE;
            int dstWidth = srcWidth;
            int dstHeight = srcHeight;
            float scale = 0.0F;
            if (srcWidth > dstMaxSize) {
               dstWidth = dstMaxSize;
               scale = (float)srcWidth / (float)dstMaxSize;
               dstHeight = Math.round((float)srcHeight / scale);
            }

            srcHeight = dstHeight;
            if (srcHeight > dstMaxSize) {
               dstHeight = dstMaxSize;
               scale = (float)srcHeight / (float)dstMaxSize;
               dstWidth = Math.round((float)dstWidth / scale);
            }

            tagImage = new BufferedImage(dstWidth, dstHeight, 1);
            tagImage.getGraphics().drawImage(srcImage, 0, 0, dstWidth, dstHeight, (ImageObserver)null);
            fileOutputStream = new FileOutputStream(fileRelatePath);
            ImageIO.write(tagImage, "jpeg", fileOutputStream);
            fileOutputStream.close();
            fileOutputStream = null;
         } finally {
            if (fileOutputStream != null) {
               try {
                  fileOutputStream.close();
               } catch (Exception var20) {
                  Exception e = var20;
                  logger.error(e);
               }

               fileOutputStream = null;
            }

            encoder = null;
            tagImage = null;
            srcImage = null;
            System.gc();
         }

         return fileRelatePath;
      }
   }

   public static UploadImgInfo UploadImage(String strImg, String category) throws Exception {
      strImg = strImg.substring(strImg.lastIndexOf(",") + 1);
      UploadImgInfo uploadImgInfo = new UploadImgInfo();
      CoreUser user = UserUtil.getUser();
      if (user == null) {
         logger.info("获取用户对象失败,采用随机码...");
         user = new CoreUser();
         user.setUsername(StringUtils.getRandomCharAndNumr(8));
      }

      String commonName = user.getUsername() + DateUtil.dateToStr(new Date(), "yyyyMMddHHmmssSSS");
      String fileName = getUploadFileName(commonName);
      String filePath = makeImage(strImg, fileName, CoreYmlConstants.getPortalShareFileDir(), category);
      uploadImgInfo.setFileName(fileName);
      File f = new File(CoreYmlConstants.getPortalShareFileDir() + filePath);
      if (f.exists() && f.isFile()) {
         uploadImgInfo.setFileSize(String.valueOf(f.length()));
      } else {
         uploadImgInfo.setFileSize("0");
      }

      uploadImgInfo.setFilePath(filePath);
      uploadImgInfo.setFileHttpPath(CoreYmlConstants.getPortalShareUrlDir() + filePath);
      return uploadImgInfo;
   }

   public static synchronized int getNextImageIndex() {
      int imgIndex = 10000;
      if (currentImageIndex > imgIndex) {
         currentImageIndex = 0;
      }

      return currentImageIndex++;
   }

   public static String getAttachPath(String param) {
      String path = ((Environment)BeanTools.getBean(Environment.class)).getProperty("linkcrm.attachment.path");
      if (StringUtils.isNotBlank(param) && !param.startsWith("http")) {
         return path + param;
      } else {
         return StringUtils.isBlank(param) ? path + "empty.jpg" : param;
      }
   }

   public static String generateFile(MultipartFile myfile, String fileFolder, String desfileName) throws Exception {
      String relativePath = fileFolder + "/" + desfileName;
      BufferedOutputStream bufferedOutputStream = null;
      BufferedInputStream bufferedInputStream = null;
      File file = new File(fileFolder);
      if (!file.exists()) {
         logger.info("文件夹路径不存在，创建文件夹【" + fileFolder + "】");
         boolean isCreateSuccess = file.mkdirs();
         if (isCreateSuccess) {
            logger.info("Create folder【" + fileFolder + "】 Success");
         } else {
            logger.error("Create folder 【" + fileFolder + "】 Failed");
         }
      }

      if (!file.isDirectory()) {
         logger.error(fileFolder + "is not a file directory!");
      } else if (!file.canRead()) {
         logger.error("this folder can't be read " + fileFolder);
      } else if (!file.canWrite()) {
         logger.error("this folder can't be write " + fileFolder);
      }

      file = new File(relativePath);
      if (file.exists()) {
         throw new Exception("文件已经存在，保存文件失败！");
      } else {
         try {
            bufferedOutputStream = new BufferedOutputStream(new FileOutputStream(relativePath));
            bufferedInputStream = new BufferedInputStream(myfile.getInputStream());
            byte[] bytes = new byte[1024];
            int num = false;

            int num;
            while((num = bufferedInputStream.read(bytes)) != -1) {
               bufferedOutputStream.write(bytes, 0, num);
               bufferedOutputStream.flush();
            }
         } catch (FileNotFoundException var19) {
            FileNotFoundException e = var19;
            e.printStackTrace();
         } catch (IOException var20) {
            IOException e = var20;
            e.printStackTrace();
         } finally {
            try {
               bufferedOutputStream.close();
               bufferedInputStream.close();
            } catch (IOException var18) {
               IOException e = var18;
               e.printStackTrace();
            }

         }

         return relativePath;
      }
   }

   public static void generateFile(String src, String fileFolder, String desfileName) throws Exception {
      String relativePath = fileFolder + "/" + desfileName;
      BufferedOutputStream bufferedOutputStream = null;
      BufferedInputStream bufferedInputStream = null;
      File file = new File(fileFolder);
      if (!file.exists()) {
         logger.info("文件夹路径不存在，创建文件夹【" + fileFolder + "】");
         boolean isCreateSuccess = file.mkdirs();
         if (isCreateSuccess) {
            logger.info("Create folder【" + fileFolder + "】 Success");
         } else {
            logger.error("Create folder 【" + fileFolder + "】 Failed");
         }
      }

      if (!file.isDirectory()) {
         logger.error(fileFolder + "is not a file directory!");
      } else if (!file.canRead()) {
         logger.error("this folder can't be read " + fileFolder);
      } else if (!file.canWrite()) {
         logger.error("this folder can't be write " + fileFolder);
      }

      file = new File(relativePath);
      if (file.exists()) {
         throw new Exception("文件已经存在，保存文件失败！");
      } else {
         try {
            bufferedOutputStream = new BufferedOutputStream(new FileOutputStream(relativePath));
            bufferedInputStream = new BufferedInputStream(new FileInputStream(src));
            byte[] bytes = new byte[1024];
            int num = false;

            int num;
            while((num = bufferedInputStream.read(bytes)) != -1) {
               bufferedOutputStream.write(bytes, 0, num);
               bufferedOutputStream.flush();
            }
         } catch (FileNotFoundException var19) {
            FileNotFoundException e = var19;
            e.printStackTrace();
         } catch (IOException var20) {
            IOException e = var20;
            e.printStackTrace();
         } finally {
            try {
               bufferedOutputStream.close();
               bufferedInputStream.close();
            } catch (IOException var18) {
               IOException e = var18;
               e.printStackTrace();
            }

         }

      }
   }

   public static String getImageBinary(String strImg, String fileType) {
      File file = new File(strImg);
      String binaryImg = "";
      BASE64Encoder encoder1 = new BASE64Encoder();

      try {
         BufferedImage bi = ImageIO.read(file);
         ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
         ImageIO.write(bi, fileType, byteArrayOutputStream);
         byte[] bytes = byteArrayOutputStream.toByteArray();
         binaryImg = encoder1.encodeBuffer(bytes).trim();
         return binaryImg;
      } catch (IOException var8) {
         IOException e = var8;
         LCLogger.withException(e);
         return null;
      }
   }

   public static MultipartFile changeToMulti(String src) throws Exception {
      File file = new File(src);
      InputStream inputStream = new FileInputStream(file);
      MultipartFile multipartFile = new MockMultipartFile(file.getName(), file.getName(), ContentType.APPLICATION_OCTET_STREAM.toString(), inputStream);
      return multipartFile;
   }
}
